<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>OptionsToolBarFocus</name>
    <message>
        <location filename="../OptionsToolBarFocusInit.js" line="+2"/>
        <source>&amp;Focus on Options Toolbar</source>
        <translation type="unfinished">Skočit na panel Nastavení</translation>
    </message>
</context>
</TS>
